@@ -18,4 +18,7 @@ which gnome-autogen.sh || {
     exit 1
 }
 
-REQUIRED_INTLTOOL_VERSION=0.40.0 REQUIRED_AUTOMAKE_VERSION=1.9 REQUIRED_GNOME_DOC_UTILS_VERSION=0.9.0 . gnome-autogen.sh
+REQUIRED_INTLTOOL_VERSION=0.40.4
+REQUIRED_AUTOMAKE_VERSION=1.9
+REQUIRED_GNOME_DOC_UTILS_VERSION=0.9.0
+. gnome-autogen.sh
